@@ -135,7 +135,7 @@
 #define XFWM_FLAG_DRAW_ACTIVE           (1L<<17)
 #define XFWM_FLAG_SEEN_ACTIVE           (1L<<18)
 #define XFWM_FLAG_FIRST_MAP             (1L<<19)
-#define XFWM_FLAG_LEGACY_FULLSCREEN     (1L<<20)
+#define XFWM_FLAG_SAVED_POS             (1L<<20)
 #define XFWM_FLAG_MOVING_RESIZING       (1L<<21)
 #define XFWM_FLAG_NEEDS_REDRAW          (1L<<22)
 #define XFWM_FLAG_OPACITY_LOCKED        (1L<<23)
@@ -180,11 +180,10 @@
                                         XFWM_FLAG_FIRST_MAP | \
                                         XFWM_FLAG_NEEDS_REDRAW
 
-#define ALL_WORKSPACES                  (int) 0xFFFFFFFF
+#define ALL_WORKSPACES                  (guint) 0xFFFFFFFF
 
 #define CONSTRAINED_WINDOW(c)           ((c->win_layer > WIN_LAYER_DESKTOP) && \
-                                        !(c->type & (WINDOW_DESKTOP | WINDOW_DOCK)) && \
-                                        !FLAG_TEST(c->xfwm_flags, XFWM_FLAG_LEGACY_FULLSCREEN))
+                                        !(c->type & (WINDOW_DESKTOP | WINDOW_DOCK)))
 
 #define WINDOW_TYPE_DIALOG              (WINDOW_DIALOG | \
                                          WINDOW_MODAL_DIALOG)
@@ -214,15 +213,15 @@
 #define CLIENT_CAN_HIDE_WINDOW(c)       (!(c->transient_for) && \
                                          FLAG_TEST(c->xfwm_flags, XFWM_FLAG_HAS_HIDE) && \
                                          !FLAG_TEST(c->flags, CLIENT_FLAG_SKIP_TASKBAR))
-#define CLIENT_CAN_MAXIMIZE_WINDOW(c)   (FLAG_TEST_AND_NOT(c->xfwm_flags, XFWM_FLAG_HAS_MAXIMIZE | \
-                                                                          XFWM_FLAG_HAS_RESIZE | \
-                                                                          XFWM_FLAG_IS_RESIZABLE, \
-                                                                          XFWM_FLAG_LEGACY_FULLSCREEN) && \
+#define CLIENT_CAN_MAXIMIZE_WINDOW(c)   (FLAG_TEST(c->xfwm_flags, XFWM_FLAG_HAS_MAXIMIZE | \
+                                                                  XFWM_FLAG_HAS_RESIZE | \
+                                                                  XFWM_FLAG_IS_RESIZABLE) && \
                                          !FLAG_TEST (c->flags, CLIENT_FLAG_FULLSCREEN))
-#define CLIENT_CAN_FILL_WINDOW(c)       (FLAG_TEST_AND_NOT(c->xfwm_flags, XFWM_FLAG_HAS_RESIZE | \
-                                                                          XFWM_FLAG_IS_RESIZABLE, \
-                                                                          XFWM_FLAG_LEGACY_FULLSCREEN) && \
+#define CLIENT_CAN_FILL_WINDOW(c)       (FLAG_TEST(c->xfwm_flags, XFWM_FLAG_HAS_RESIZE | \
+                                                                  XFWM_FLAG_IS_RESIZABLE) && \
                                          !FLAG_TEST (c->flags, CLIENT_FLAG_FULLSCREEN | CLIENT_FLAG_MAXIMIZED))
+#define CLIENT_CAN_TILE_WINDOW(c)       (CLIENT_CAN_MAXIMIZE_WINDOW(c) && \
+                                         (c->type & WINDOW_NORMAL))
 
 typedef enum
 {
@@ -239,6 +238,16 @@ typedef enum
 }
 netWindowType;
 
+typedef enum
+{
+    TILE_NONE = 0,
+    TILE_LEFT,
+    TILE_RIGHT,
+    TILE_DOWN,
+    TILE_UP
+}
+tilePositionType;
+
 struct _Client
 {
     /* Reference to our screen structure */
@@ -257,8 +266,6 @@ struct _Client
     Window group_leader;
     xfwmPixmap appmenu[STATE_TOGGLED];
     Colormap cmap;
-    unsigned long win_hints;
-    unsigned long win_state;
     unsigned long win_layer;
     unsigned long serial;
     unsigned long initial_layer;
@@ -279,6 +286,8 @@ struct _Client
     gint gravity;
     guint win_workspace;
     unsigned int ignore_unmap;
+    gint saved_x;
+    gint saved_y;
     gint old_x;
     gint old_y;
     gint old_width;
@@ -364,7 +373,8 @@ void                     clientGetMWMHints                      (Client *,
 void                     clientGetWMNormalHints                 (Client *,
                                                                  gboolean);
 void                     clientGetWMProtocols                   (Client *);
-void                     clientUpdateIcon                       (Client * c);
+void                     clientUpdateIcon                       (Client *);
+void                     clientSaveSizePos                      (Client *);
 Client                  *clientFrame                            (DisplayInfo *,
                                                                  Window,
                                                                  gboolean);
@@ -423,9 +433,14 @@ void                     clientToggleLayerAbove                 (Client *);
 void                     clientToggleLayerBelow                 (Client *);
 void                     clientSetLayerNormal                   (Client *);
 void                     clientRemoveMaximizeFlag               (Client *);
-void                     clientToggleMaximized                  (Client *,
+gboolean                 clientToggleMaximized                  (Client *,
                                                                  int,
                                                                  gboolean);
+gboolean                 clientTile                             (Client *,
+                                                                 gint,
+                                                                 gint,
+                                                                 tilePositionType,
+                                                                 gboolean);
 void                     clientUpdateOpacity                    (Client *);
 void                     clientUpdateAllOpacity                 (ScreenInfo *);
 void                     clientSetOpacity                       (Client *,
@@ -433,6 +448,8 @@ void                     clientSetOpacity                       (Client *,
                                                                  guint, guint);
 void                     clientIncOpacity                       (Client *);
 void                     clientDecOpacity                       (Client *);
+void                     clientUpdateCursor                     (Client *);
+void                     clientUpdateAllCursor                  (ScreenInfo *);
 void                     clientScreenResize                     (ScreenInfo *,
                                                                  gboolean);
 void                     clientButtonPress                      (Client *,
